@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2016, Phoronix Media
-	Copyright (C) 2010 - 2016, Michael Larabel
+	Copyright (C) 2010 - 2017, Phoronix Media
+	Copyright (C) 2010 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -69,6 +69,7 @@ class pts_test_installer
 
 		// Setup the install manager and add the tests
 		$test_install_manager = new pts_test_install_manager();
+		$install_table = array();
 
 		foreach($test_profiles as &$test_profile)
 		{
@@ -81,27 +82,32 @@ class pts_test_installer
 			{
 				if($test_profile->is_supported(false) == false)
 				{
-					pts_client::$display->generic_sub_heading('Not Supported: ' . $test_profile->get_identifier());
+					$install_table[] = array('Not Supported:', $test_profile->get_identifier());
 				}
 				else if($test_install_manager->add_test_profile($test_profile) != false)
 				{
-					pts_client::$display->generic_sub_heading('To Install: ' . $test_profile->get_identifier());
+					$install_table[] = array('To Install:', $test_profile->get_identifier());
 				}
 			}
 			else
 			{
-				pts_client::$display->generic_sub_heading('Installed: ' . $test_profile->get_identifier());
+					$install_table[] = array('Installed:', $test_profile->get_identifier());
 			}
 		}
 
 		if($unknown_tests)
 		{
-			foreach($unknown_tests as $unkown)
+			foreach($unknown_tests as $unknown)
 			{
-				pts_client::$display->generic_sub_heading('Unknown: ' . $unkown);
+				$install_table[] = array('Unknown:', $unknown);
 			}
 		}
 
+		foreach($install_table as $line)
+		{
+			pts_client::$display->generic_sub_heading(pts_client::cli_just_bold($line[0]) . (str_repeat(' ', (15 - strlen($line[0])))) . $line[1]);
+		}
+
 		if($test_install_manager->tests_to_install_count() == 0)
 		{
 			return true;
@@ -737,7 +743,7 @@ class pts_test_installer
 				pts_client::$display->display_interrupt_message($pre_install_message);
 				$install_time_length_start = microtime(true);
 				$install_log = pts_tests::call_test_script($test_install_request->test_profile, 'install', null, $test_install_directory, $test_install_request->special_environment_vars, false);
-				$test_install_request->install_time_duration = ceil(microtime(true) - $install_time_length_start);
+				$test_install_request->install_time_duration = microtime(true) - $install_time_length_start;
 				pts_client::$display->display_interrupt_message($post_install_message);
 
 				if(!empty($install_log))
