@@ -636,6 +636,17 @@ class pts_test_run_manager
 			// There already is a match for this test in this particular result buffer
 			return true;
 		}
+		$skip_tests_with_args = ($e = pts_client::read_env('SKIP_TESTS_HAVING_ARGS')) ? pts_strings::comma_explode($e) : false;
+		if($skip_tests_with_args)
+		{
+			foreach($skip_tests_with_args as $skip_test_if_arg_matches)
+			{
+				if(stripos($test_run_request->get_arguments_description(), $skip_test_if_arg_matches) !== false)
+				{
+					return true;
+				}
+			}
+		}
 
 		$test_successful = pts_test_execution::run_test($this, $test_run_request);
 
@@ -1338,6 +1349,13 @@ class pts_test_run_manager
 		{
 			if($this->validate_test_to_run($result_object->test_profile))
 			{
+
+				// Check to ensure that nothing extra may have somehow wound up in the execution argument string of a saved result file...
+				if(pts_strings::has_in_string($result_object->get_arguments(), array(';', '&&', '|')))
+				{
+					echo PHP_EOL . 'Exception loading a result object.' . PHP_EOL;
+					continue;
+				}
 				$test_result = new pts_test_result($result_object->test_profile);
 				$test_result->set_used_arguments($result_object->get_arguments());
 				$test_result->set_used_arguments_description($result_object->get_arguments_description());
@@ -1348,38 +1366,6 @@ class pts_test_run_manager
 		// Is there something to run?
 		return $this->get_test_count() > 0;
 	}
-	public function load_test_run_requests_to_run($save_name, $result_identifier, &$result_file, &$test_run_requests)
-	{
-		// Determine what to run
-		$this->auto_save_results($save_name, $result_identifier);
-		$this->run_description = $result_file->get_description();
-
-		if(count($test_run_requests) == 0)
-		{
-			return false;
-		}
-
-		foreach($test_run_requests as &$test_run_request)
-		{
-			if($this->validate_test_to_run($test_run_request->test_profile) == false)
-			{
-				continue;
-			}
-
-			if($test_run_request->test_profile->get_override_values() != null)
-			{
-				$test_run_request->test_profile->set_override_values($test_run_request->test_profile->get_override_values());
-			}
-
-			$test_result = new pts_test_result($test_run_request->test_profile);
-			$test_result->set_used_arguments($test_run_request->get_arguments());
-			$test_result->set_used_arguments_description($test_run_request->get_arguments_description());
-			$this->add_test_result_object($test_result);
-		}
-
-		// Is there something to run?
-		return $this->get_test_count() > 0;
-	}
 	public function is_multi_test_stress_run()
 	{
 		return $this->multi_test_stress_run;
@@ -1482,6 +1468,12 @@ class pts_test_run_manager
 						continue;
 					}
 
+					// Check to ensure that nothing extra may have somehow wound up in the execution argument string of a saved result file...
+					if(pts_strings::has_in_string($result_object->get_arguments(), array(';', '&&', '|')))
+					{
+						continue;
+					}
+
 					$test_result = new pts_test_result($result_object->test_profile);
 					$test_result->set_used_arguments($result_object->get_arguments());
 					$test_result->set_used_arguments_description($result_object->get_arguments_description());
@@ -1617,12 +1609,12 @@ class pts_test_run_manager
 		}
 		else if(pts_client::read_env('NO_' . strtoupper($test_type) . '_TESTS') ||($skip_tests && (in_array($test_profile, $skip_tests) || in_array($test_type, $skip_tests) || in_array($test_profile->get_identifier(false), $skip_tests) || in_array($test_profile->get_identifier_base_name(), $skip_tests))))
 		{
-			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
+			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environment variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
 		}
 		else if($skip_test_subsystems && in_array(strtolower($test_profile->get_test_hardware_type()), $skip_test_subsystems))
 		{
-			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
+			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environment variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
 		}
 		else if($test_profile->is_root_required() && $this->batch_mode && phodevi::is_root() == false)
