@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2015, Phoronix Media
-	Copyright (C) 2009 - 2015, Michael Larabel
+	Copyright (C) 2009 - 2017, Phoronix Media
+	Copyright (C) 2009 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@ class cpu_power extends phodevi_sensor
 {
 	const SENSOR_TYPE = 'cpu';
 	const SENSOR_SENSES = 'power';
-	const SENSOR_UNIT = 'Watts';
-
 
 	public function read_sensor()
 	{
@@ -35,10 +33,25 @@ class cpu_power extends phodevi_sensor
 		}
 		return -1;		// TODO make -1 a named constant
 	}
+	public static function get_unit()
+	{
+		$unit = null;
+
+		if(is_readable('/sys/bus/i2c/drivers/ina3221x/0-0041/iio:device1/in_power1_input'))
+		{
+			$unit = 'Milliwatts';
+		}
+		else
+		{
+			$unit = 'Watts';
+		}
+
+		return $unit;
+	}
 
 	private function cpu_power_linux()
 	{
-		$cpu_watts = -1;
+		$cpu_power = -1;
 
 		// Try hwmon interface for AMD 15h (Bulldozer FX CPUs) where this support was introduced for AMD CPUs and exposed by the fam15h_power hwmon driver
 		// The fam15h_power driver doesn't expose the power consumption on a per-core/per-package basis but only an average
@@ -52,10 +65,18 @@ class cpu_power extends phodevi_sensor
 				$hwmon_watts = $hwmon_watts / 1000000;
 			}
 
-			$cpu_watts = pts_math::set_precision($hwmon_watts, 2);
+			$cpu_power = pts_math::set_precision($hwmon_watts, 2);
+		}
+		else if(is_readable('/sys/bus/i2c/drivers/ina3221x/0-0041/iio:device1/in_power1_input'))
+		{
+			$in_power1_input = pts_file_io::file_get_contents('/sys/bus/i2c/drivers/ina3221x/0-0041/iio:device1/in_power1_input');
+			if(is_numeric($in_power1_input) && $in_power1_input > 1)
+			{
+				$cpu_power = $in_power1_input;
+			}
 		}
 
-		return $cpu_watts;
+		return $cpu_power;
 	}
 }
 
