@@ -120,7 +120,28 @@ abstract class pts_graph_core
 		}
 		else if(PTS_IS_CLIENT && pts_client::read_env('GRAPH_HIGHLIGHT') != false)
 		{
-			$this->value_highlights = pts_strings::comma_explode(pts_client::read_env('GRAPH_HIGHLIGHT'));
+			//$this->value_highlights = pts_strings::comma_explode(pts_client::read_env('GRAPH_HIGHLIGHT'));
+			// We support GRAPH_HIGHLIGHT as a series of
+			// ID, ID=colorId or ID=color values, e.g.
+			// GRAPH_HIGHLIGHT="will_be_different,group1a=1,group1b=1,blue=#0000ff"
+			foreach(pts_strings::comma_explode(pts_client::read_env('GRAPH_HIGHLIGHT')) as $id)
+			{
+				$split = explode('=', $id);
+				if(count($split) == 2)
+				{
+					$this->value_highlights[$split[0]] = null;
+					$color = $split[1];
+					if(is_numeric($color)) // TODO clean this up with a better color check
+					{
+						$color = self::$c['color']['paint'][$color];
+						$this->value_highlights[$split[0]] = $color;
+					}
+				}
+				else
+				{
+					$this->value_highlights[$id] = null;
+				}
+			}
 		}
 		if(isset($extra_attributes['force_simple_keys']))
 		{
@@ -176,6 +197,13 @@ abstract class pts_graph_core
 						continue;
 						break;
 				}
+				/*if(in_array($buffer_item->get_result_identifier(), $this->graph_identifiers))
+				{
+					// Don't allow duplicate identifiers
+					unset($this->test_result->test_result_buffer->buffer_items[$i]);
+					continue;
+
+				}*/
 
 				$buffer_item->reset_result_identifier($system);
 
@@ -202,6 +230,13 @@ abstract class pts_graph_core
 					unset($this->test_result->test_result_buffer->buffer_items[$i]);
 					continue;
 				}
+				if(in_array($buffer_item->get_result_identifier(), $this->graph_identifiers))
+				{
+					// Don't allow duplicate identifiers
+					unset($this->test_result->test_result_buffer->buffer_items[$i]);
+					continue;
+
+				}
 
 				$this->graph_identifiers[] = $buffer_item->get_result_identifier();
 			}
@@ -494,10 +529,10 @@ abstract class pts_graph_core
 				}
 				else
 				{
-					$longest_identifier_width = ceil(self::text_string_width($longest_identifier, $this->i['identifier_size']) * 1.065) + 10;
+					$longest_identifier_width = ceil(self::text_string_width($longest_identifier, $this->i['identifier_size']) * 1.09) + 12;
 				}
 
-				$longest_identifier_max = ($this->i['graph_width'] * 0.5) + 0.01;
+				$longest_identifier_max = ceil(($this->i['graph_width'] * 0.55) + 0.01);
 
 				$this->i['left_start'] = min($longest_identifier_max, max($longest_identifier_width, 70));
 				$this->i['left_end_right'] = 15;
@@ -542,7 +577,7 @@ abstract class pts_graph_core
 					{
 						// this is to avoid having a rotated text bar overrun other results
 						// XXX the 50 number might be too hacky
-						$per_identifier_height = max(54, ceil($rotated_text / count($this->results) * 1.1));
+						$per_identifier_height = max(30, ceil($rotated_text / count($this->results) * 1.1));
 					}
 				}
 				else if(count($this->results) > 3)
@@ -561,15 +596,10 @@ abstract class pts_graph_core
 					{
 						$per_identifier_height = 36;
 					}
-					else if($id_count <= 38)
-					{
-						$this->i['compact_result_view'] = true;
-						$per_identifier_height = 30;
-					}
 					else
 					{
 						$this->i['compact_result_view'] = true;
-						$per_identifier_height = 26;
+						$per_identifier_height = 28;
 					}
 				}
 
@@ -866,7 +896,7 @@ abstract class pts_graph_core
 
 		$this->i['key_line_height'] = 16;
 		$ak = array_keys($this->results);
-		$this->i['key_item_width'] = 20 + self::text_string_width(pts_strings::find_longest_string($ak), self::$c['size']['key']);
+		$this->i['key_item_width'] = 24 + ceil(self::text_string_width(pts_strings::find_longest_string($ak), self::$c['size']['key']) * 1.05);
 		$this->i['keys_per_line'] = max(1, floor(($this->i['graph_left_end'] - $this->i['left_start']) / $this->i['key_item_width']));
 
 		return ceil(count($this->results) / $this->i['keys_per_line']) * $this->i['key_line_height'];
@@ -939,6 +969,16 @@ abstract class pts_graph_core
 
 		$this->svg_dom->add_element('polygon', array('points' => implode(' ', $arrow_points), 'fill' => $background_color, 'stroke' => $border_color, 'stroke-width' => $border_width));
 	}
+	protected function adjust_color($identifier, $paint_color)
+	{
+		// Adjust the color based on the identifier and the content of value_highlights
+		if(array_key_exists($identifier, $this->value_highlights))
+		{
+			$color = $this->value_highlights[$identifier];
+			$paint_color = empty($color) ? $this->darken_color($paint_color) : $color;
+		}
+		return $paint_color;
+	}
 	protected static function text_string_width($string, $size)
 	{
 		$dimensions = pts_svg_dom::estimate_text_dimensions($string, $size);
