@@ -159,7 +159,7 @@ class pts_render
 			$result_identifiers = $result_object->test_result_buffer->get_identifiers();
 
 			// COMPACT PROCESS
-			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && ($result_file->get_system_count() > 7 || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes)))
+			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && ($result_file->get_system_count() > 5 || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes)))
 			{
 				// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
 				$extra_attributes['compact_to_scalar'] = true;
@@ -441,6 +441,7 @@ class pts_render
 						break;
 					}
 
+					$intersect = array();
 					if($key == 'compiler-options')
 					{
 						$intersect = count($unique_compiler_data) == 1 ? reset($unique_compiler_data) : call_user_func_array('array_intersect', $unique_compiler_data);
@@ -476,7 +477,7 @@ class pts_render
 			}
 			if(isset($data['max-result']))
 			{
-				$graph_identifier_note .= ($graph_identifier_note == null ? '' : ' / ') . 'MAX: ' . $data['min-result'];
+				$graph_identifier_note .= ($graph_identifier_note == null ? '' : ' / ') . 'MAX: ' . $data['max-result'];
 			}
 
 			if($graph_identifier_note)
