@@ -267,6 +267,25 @@ class pts_result_file
 	{
 		return count($this->get_result_objects());
 	}
+	public function has_matching_test_and_run_identifier(&$test_result, $run_identifier_to_check)
+	{
+		$found_match = false;
+		$hash_to_check = $test_result->get_comparison_hash();
+
+		foreach($this->get_result_objects() as $result_object)
+		{
+			if($hash_to_check == $result_object->get_comparison_hash())
+			{
+				if(in_array($run_identifier_to_check, $result_object->test_result_buffer->get_identifiers()))
+				{
+					$found_match = true;
+				}
+				break;
+			}
+		}
+
+		return $found_match;
+	}
 	public function get_contained_tests_hash($raw_output = true)
 	{
 		$result_object_hashes = $this->get_result_object_hashes();
