@@ -66,6 +66,18 @@ class pts_test_result
 	{
 		if(strpos(' ' . $this->used_arguments_description . ' ', ' ' . $arguments_description . ' ') === false)
 		{
+			if(($x = strpos($arguments_description, ': ')) !== false)
+			{
+				$prefix_being_added = substr($arguments_description, 0, $x);
+
+				// Remove the old prefix to avoid when re-running tests that it could see multiple things appended from older version
+				// Encountered when introducing the append to test arguments for Mad Max test profile
+				if(($x = strpos($this->used_arguments_description, ' ' . $prefix_being_added)) !== false)
+				{
+					$this->used_arguments_description = substr($this->used_arguments_description, 0, $x);
+				}
+			}
+
 			$this->used_arguments_description .= ($this->used_arguments_description != null ? ' ' : null) . $arguments_description;
 		}
 	}
@@ -260,13 +272,7 @@ class pts_test_result
 			{
 				foreach($keys as $k)
 				{
-					if($is_multi_way && strpos($this->test_result_buffer->buffer_items[$k]->get_result_identifier(), ': ' . $normalize_against) !== false)
-					{
-						// This allows it to just normalize against part of the string
-						$divide_value = $this->test_result_buffer->buffer_items[$k]->get_result_value();
-						break;
-					}
-					else if($this->test_result_buffer->buffer_items[$k]->get_result_identifier() == $normalize_against)
+					if(strpos($this->test_result_buffer->buffer_items[$k]->get_result_identifier(), $normalize_against) !== false)
 					{
 						$divide_value = $this->test_result_buffer->buffer_items[$k]->get_result_value();
 						break;
