@@ -559,7 +559,8 @@ class pts_test_result_parser
 			$line_before_hint = isset($entry->LineBeforeHint) ? $entry->LineBeforeHint->__toString() : null;
 			$line_after_hint = isset($entry->LineAfterHint) ? $entry->LineAfterHint->__toString() : null;
 			$line_hint = isset($entry->LineHint) ? $entry->LineHint->__toString() : null;
-			$search_key = self::determine_search_key($line_hint, $line_before_hint, $line_after_hint, $template_line, $template, $template_r, $key_for_result); // SEARCH KEY
+			$chars_to_space = isset($entry->TurnCharsToSpace) ? $entry->TurnCharsToSpace->__toString() : null;
+			$search_key = self::determine_search_key($output, $line_hint, $line_before_hint, $line_after_hint, $template_line, $template, $template_r, $key_for_result); // SEARCH KEY
 			pts_client::test_profile_debug_message('Search Key: ' . $search_key);
 			if($search_key != null || $line_before_hint != null || $line_after_hint != null || $template_r[0] == $key_for_result)
 			{
@@ -570,6 +571,7 @@ class pts_test_result_parser
 				do
 				{
 					$count = count($test_results);
+					$possible_lines = array();
 
 					if($line_before_hint != null)
 					{
@@ -587,12 +589,21 @@ class pts_test_result_parser
 					}
 					else if($search_key != null)
 					{
-						$search_key = trim($search_key);
-						pts_client::test_profile_debug_message('Result Parsing Search Key: ' . $search_key);
-						$line = substr($output, 0, strpos($output, "\n", strrpos($output, $search_key)));
-						$start_of_line = strrpos($line, "\n");
-						$output = substr($line, 0, $start_of_line) . "\n";
-						$line = substr($line, $start_of_line + 1);
+						if(trim($search_key) != null)
+						{
+							$search_key = trim($search_key);
+						}
+						pts_client::test_profile_debug_message('Result Parsing Search Key: "' . $search_key . '"');
+
+						while(($line_x = strrpos($output, $search_key)) !== false)
+						{
+							$line = substr($output, 0, strpos($output, "\n", $line_x));
+							$start_of_line = strrpos($line, "\n");
+							$output = substr($line, 0, $start_of_line) . "\n";
+							$possible_lines[] = substr($line, $start_of_line + 1);
+						}
+
+						$line = !empty($possible_lines) ? array_shift($possible_lines) : null;
 					}
 					else
 					{
@@ -600,6 +611,10 @@ class pts_test_result_parser
 						pts_client::test_profile_debug_message('No Result Parsing Hint, Including Entire Result Output');
 						$line = trim($output);
 					}
+					if(!empty($chars_to_space))
+					{
+						$line = str_replace($chars_to_space, ' ', $line);
+					}
 					pts_client::test_profile_debug_message('Result Line: ' . $line);
 
 					// FALLBACK HELPERS FOR BELOW
@@ -615,9 +630,11 @@ class pts_test_result_parser
 						{
 							// Using ResultBeforeString tag
 							$before_this = array_search($before_string, $r);
-							if($before_this !== false)
+							$possible_res = $r[($before_this - 1)];
+							self::strip_result_cleaner($possible_res, $entry);
+							if($before_this !== false && (!$is_numeric_check || is_numeric($possible_res)))
 							{
-								$test_results[] = $r[($before_this - 1)];
+								$test_results[] = $possible_res;
 							}
 						}
 						else if(!empty($after_string))
@@ -634,14 +651,36 @@ class pts_test_result_parser
 									{
 										continue;
 									}
-									$test_results[] = $r[$f];
+									self::strip_result_cleaner($r[$f], $entry);
+									if(!$is_numeric_check || is_numeric($r[$f]))
+									{
+										$test_results[] = $r[$f];
+									}
 									break;
 								}
 							}
 						}
 						else if(isset($r[$template_r_pos]))
 						{
-							$test_results[] = $r[$template_r_pos];
+							self::strip_result_cleaner($r[$template_r_pos], $entry);
+							if(!$is_numeric_check || is_numeric($r[$template_r_pos]))
+							{
+								$test_results[] = $r[$template_r_pos];
+							}
+							else if($is_numeric_check && strpos($r[$template_r_pos], ':') !== false && strpos($r[$template_r_pos], '.') !== false && is_numeric(str_replace(array(':', '.'), null, $r[$template_r_pos])) && stripos($line, 'time') !== false)
+							{
+								// Convert e.g. 03:03.17 to seconds, relevant for at least pts/blender
+								$seconds = 0;
+								$formatted_time = $r[$template_r_pos];
+								if(($c = strpos($formatted_time, ':')) !== false && strrpos($formatted_time, ':') == $c && is_numeric(substr($formatted_time, 0, $c)))
+								{
+									$seconds = (substr($formatted_time, 0, $c) * 60) + substr($formatted_time, ($c + 1));
+								}
+								if(!empty($seconds))
+								{
+									$test_results[] = $seconds;
+								}
+							}
 						}
 						else
 						{
@@ -653,6 +692,17 @@ class pts_test_result_parser
 								$try_again = true;
 							}
 						}
+						if($try_again == false && empty($test_results) && !empty($possible_lines))
+						{
+							$line = array_shift($possible_lines);
+							pts_client::test_profile_debug_message('Trying Backup Result Line: ' . $line);
+							$try_again = true;
+						}
+						else if(!empty($test_results) && $is_multi_match && !empty($possible_lines) && $search_key != null)
+						{
+							// Rebuild output if it was disassembled in search key code above
+							$output = implode(PHP_EOL, array_reverse($possible_lines)) . PHP_EOL;
+						}
 					}
 					while($try_again);
 				}
@@ -666,21 +716,12 @@ class pts_test_result_parser
 			return false;
 		}
 
-		$strip_from_result = isset($entry->StripFromResult) ? $entry->StripFromResult->__toString() : null;
 		$multiply_by = isset($entry->MultiplyResultBy) ? $entry->MultiplyResultBy->__toString() : null;
-		$strip_result_postfix = isset($entry->StripResultPostfix) ? $entry->StripResultPostfix->__toString() : null;
 		$divide_by = isset($entry->DivideResultBy) ? $entry->DivideResultBy->__toString() : null;
 
 		foreach($test_results as $x => &$test_result)
 		{
-			if($strip_from_result != null)
-			{
-				$test_result = str_replace($strip_from_result, null, $test_result);
-			}
-			if($strip_result_postfix != null && substr($test_result, 0 - strlen($strip_result_postfix)) == $strip_result_postfix)
-			{
-				$test_result = substr($test_result, 0, 0 - strlen($strip_result_postfix));
-			}
+			self::strip_result_cleaner($test_result, $entry);
 
 			// Expand validity checking here
 			if($is_numeric_check == true && is_numeric($test_result) == false)
@@ -755,6 +796,7 @@ class pts_test_result_parser
 			$scale = isset($entry->ResultScale) ? $entry->ResultScale->__toString() : null;
 			$proportion = isset($entry->ResultProportion) ? $entry->ResultProportion->__toString() : null;
 			$set_args_desc = isset($entry->ArgumentsDescription) ? $entry->ArgumentsDescription->__toString() : null;
+			$append_args_desc = isset($entry->AppendToArgumentsDescription) ? $entry->AppendToArgumentsDescription->__toString() : null;
 
 			if($scale != null)
 			{
@@ -772,12 +814,30 @@ class pts_test_result_parser
 			{
 				$test_run_request->set_used_arguments_description($set_args_desc);
 			}
+			if($append_args_desc != null)
+			{
+				$test_run_request->append_to_arguments_description(' - ' . $append_args_desc);
+			}
 		}
 
 		pts_client::test_profile_debug_message('Test Result Parser Returning: ' . $test_result);
 		return $test_result;
 	}
-	protected static function determine_search_key($line_hint, $line_before_hint, $line_after_hint, $template_line, $template, $template_r, $key)
+	protected static function strip_result_cleaner(&$test_result, &$entry)
+	{
+		$strip_from_result = isset($entry->StripFromResult) ? $entry->StripFromResult->__toString() : null;
+		$strip_result_postfix = isset($entry->StripResultPostfix) ? $entry->StripResultPostfix->__toString() : null;
+
+		if($strip_from_result != null)
+		{
+			$test_result = str_replace($strip_from_result, null, $test_result);
+		}
+		if($strip_result_postfix != null && substr($test_result, 0 - strlen($strip_result_postfix)) == $strip_result_postfix)
+		{
+			$test_result = substr($test_result, 0, 0 - strlen($strip_result_postfix));
+		}
+	}
+	protected static function determine_search_key(&$output, $line_hint, $line_before_hint, $line_after_hint, $template_line, $template, $template_r, $key)
 	{
 		// Determine the search key to use
 		$search_key = null;
@@ -795,13 +855,22 @@ class pts_test_result_parser
 		}
 		else
 		{
-			foreach($template_r as $line_part)
+			$first_portion_of_line = substr($template_line, 0, strpos($template_line, $key));
+			if(strpos($output, $first_portion_of_line) !== false)
 			{
-				if(strpos($line_part, ':') !== false && strlen($line_part) > 1)
+				$search_key = $first_portion_of_line;
+			}
+
+			if($search_key == null)
+			{
+				foreach($template_r as $line_part)
 				{
-					// add some sort of && strrpos($template, $line_part)  to make sure there isn't two of the same $search_key
-					$search_key = $line_part;
-					break;
+					if(strpos($line_part, ':') !== false && strlen($line_part) > 1)
+					{
+						// add some sort of && strrpos($template, $line_part)  to make sure there isn't two of the same $search_key
+						$search_key = $line_part;
+						break;
+					}
 				}
 			}
 
