@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -159,7 +159,23 @@ class phoromatic_schedules implements pts_webui_interface
 
 				$main .= '<h1>' . $row['Title'] . '</h1>';
 				$main .= '<h3>' . $row['Description'] . '</h3>';
-				$main .= '<p>This schedule was last modified on <strong>' . date('j F Y \a\t H:i', strtotime($row['LastModifiedOn'])) . '</strong> by <strong>' . $row['LastModifiedBy'] . '</strong>.';
+				switch($row['RunPriority'])
+				{
+					case 1:
+						$prio = 'Low Priority';
+						break;
+					case 100:
+						$prio = 'Default Priority';
+						break;
+					case 200:
+						$prio = 'High Priority';
+						break;
+					default:
+						$prio = $row['RunPriority'] . ' Priority';
+						break;
+				}
+
+				$main .= '<p>Priority: ' . $prio . '</p><p>This schedule was last modified on <strong>' . date('j F Y \a\t H:i', strtotime($row['LastModifiedOn'])) . '</strong> by <strong>' . $row['LastModifiedBy'] . '</strong>.';
 
 				if(!PHOROMATIC_USER_IS_VIEWER)
 				{
