@@ -109,7 +109,7 @@ function pts_define_directories()
 {
 	// User's home directory for storing results, module files, test installations, etc.
 	pts_define('PTS_CORE_PATH', PTS_PATH . 'pts-core/');
-	pts_define('PTS_IS_DAEMONIZED_SERVER_PROCESS', PTS_IS_CLIENT && is_dir('/var/lib/') && is_writable('/') ? true : false);
+	pts_define('PTS_IS_DAEMONIZED_SERVER_PROCESS', PTS_IS_CLIENT && is_writable('/var/lib/') && is_writable('/etc') ? true : false);
 
 	if(PTS_IS_DAEMONIZED_SERVER_PROCESS)
 	{
@@ -248,9 +248,9 @@ function pts_version_codenames()
 		);
 }
 
-pts_define('PTS_VERSION', '7.0.1');
-pts_define('PTS_CORE_VERSION', 7010);
-pts_define('PTS_CODENAME', 'RINGSAKER');
+pts_define('PTS_VERSION', '7.2.0');
+pts_define('PTS_CORE_VERSION', 7200);
+pts_define('PTS_CODENAME', 'TRYSIL');
 pts_define('PTS_IS_CLIENT', (defined('PTS_MODE') && strstr(PTS_MODE, 'CLIENT') !== false));
 pts_define('PTS_IS_WEB_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'WEB_CLIENT'));
 pts_define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
@@ -286,7 +286,7 @@ if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 		}
 		closedir($dh);
 	}
-	function __autoload($to_load)
+	function pts_auto_load_class($to_load)
 	{
 		static $obj_files = null;
 
@@ -301,6 +301,7 @@ if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 			unset($obj_files[$to_load]);
 		}
 	}
+	spl_autoload_register('pts_auto_load_class');
 }
 if(PTS_IS_CLIENT && ini_get('date.timezone') == null)
 {
